Daemon

Struct Daemon 

pub struct Daemon<A: Program> { /* private fields */ }

Implementations

Source

impl<P: Program> Daemon<P>

pub fn run(self) -> Result
where Self: 'static, P::Message: Debug + Send + 'static + TryInto<LayerShellCustomActionWithId, Error = P::Message>,

pub fn settings(self, settings: Settings) -> Self

pub fn antialiasing(self, antialiasing: bool) -> Self

Sets the Settings::antialiasing of the Daemon.

pub fn default_font(self, default_font: Font) -> Self

Sets the default Font of the Daemon.

pub fn layer_settings(self, layer_settings: LayerShellSettings) -> Self

Sets the layershell setting of the Daemon

pub fn font(self, font: impl Into<Cow<'static, [u8]>>) -> Self

Adds a font to the list of fonts that will be loaded at the start of the Daemon.

pub fn default_text_size<Pixels: Into<Pixels>>( self, default_text_size: Pixels, ) -> Self

set the default_text_size

pub fn style( self, f: impl Fn(&P::State, &P::Theme) -> Style, ) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>

Sets the style logic of the Daemon.

pub fn subscription( self, f: impl Fn(&P::State) -> Subscription<P::Message>, ) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>

Sets the subscription logic of the Daemon.

pub fn title( self, f: impl Fn(&P::State, Id) -> Option<String>, ) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>

Sets the subscription logic of the Daemon.

pub fn theme( self, f: impl ThemeFn<P::State, P::Theme>, ) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>

Sets the theme logic of the Daemon.

pub fn scale_factor( self, f: impl Fn(&P::State, Id) -> f32, ) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>

Sets the scale factor of the Daemon.

pub fn executor<E>( self, ) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
where E: Executor,

Sets the executor of the Daemon.