Cursor

Enum Cursor 

pub enum Cursor {
    Available(Point),
    Levitating(Point),
    Unavailable,
}
The mouse cursor state.

Variants



Available(Point)

The cursor has a defined position.



Levitating(Point)

The cursor has a defined position, but it’s levitating over a layer above.



Unavailable

The cursor is currently unavailable (i.e. out of bounds or busy).

Implementations

Source

impl Cursor

pub fn position(self) -> Option<Point>

Returns the absolute position of the Cursor, if available.

pub fn position_over(self, bounds: Rectangle) -> Option<Point>

Returns the absolute position of the Cursor, if available and inside the given bounds.

If the Cursor is not over the provided bounds, this method will return None.

pub fn position_in(self, bounds: Rectangle) -> Option<Point>

Returns the relative position of the Cursor inside the given bounds, if available.

If the Cursor is not over the provided bounds, this method will return None.

pub fn position_from(self, origin: Point) -> Option<Point>

Returns the relative position of the Cursor from the given origin, if available.

pub fn is_over(self, bounds: Rectangle) -> bool

Returns true if the Cursor is over the given bounds.

pub fn is_levitating(self) -> bool

Returns true if the Cursor is levitating over a layer above.

pub fn levitate(self) -> Cursor

Makes the Cursor levitate over a layer above.

pub fn land(self) -> Cursor

Brings the Cursor back to the current layer.