Rectangle

Struct Rectangle 

pub struct Rectangle<T = f32> {
    pub x: T,
    pub y: T,
    pub width: T,
    pub height: T,
}
An axis-aligned rectangle.

Fields

x: T

X coordinate of the top-left corner.

y: T

Y coordinate of the top-left corner.

width: T

Width of the rectangle.

height: T

Height of the rectangle.

Implementations

Source

impl<T> Rectangle<T>
where T: Default,

pub fn with_size(size: Size<T>) -> Rectangle<T>

Creates a new Rectangle with its top-left corner at the origin and with the provided Size.

Source

impl Rectangle

pub const INFINITE: Rectangle

A rectangle starting at negative infinity and with infinite width and height.

pub const fn new(top_left: Point, size: Size) -> Rectangle

Creates a new Rectangle with its top-left corner in the given Point and with the provided Size.

pub fn with_radius(radius: f32) -> Rectangle

Creates a new square Rectangle with the center at the origin and with the given radius.

pub fn with_vertices( top_left: Point, top_right: Point, bottom_left: Point, ) -> (Rectangle, Radians)

Creates a new axis-aligned Rectangle from the given vertices; returning the rotation in Radians that must be applied to the axis-aligned Rectangle to obtain the desired result.

pub fn center(&self) -> Point

Returns the Point at the center of the Rectangle.

pub fn center_x(&self) -> f32

Returns the X coordinate of the Point at the center of the Rectangle.

pub fn center_y(&self) -> f32

Returns the Y coordinate of the Point at the center of the Rectangle.

pub fn position(&self) -> Point

Returns the position of the top left corner of the Rectangle.

pub fn size(&self) -> Size

Returns the Size of the Rectangle.

pub fn area(&self) -> f32

Returns the area of the Rectangle.

pub fn contains(&self, point: Point) -> bool

Returns true if the given Point is contained in the Rectangle. Excludes the right and bottom edges.

pub fn distance(&self, point: Point) -> f32

Returns the minimum distance from the given Point to any of the edges of the Rectangle.

pub fn offset(&self, container: &Rectangle) -> Vector

Computes the offset that must be applied to the Rectangle to be placed inside the given container.

pub fn is_within(&self, container: &Rectangle) -> bool

Returns true if the current Rectangle is within the given container. Includes the right and bottom edges.

pub fn intersection(&self, other: &Rectangle) -> Option<Rectangle>

Computes the intersection with the given Rectangle.

pub fn intersects(&self, other: &Rectangle) -> bool

Returns whether the Rectangle intersects with the given one.

pub fn union(&self, other: &Rectangle) -> Rectangle

Computes the union with the given Rectangle.

pub fn snap(self) -> Option<Rectangle<u32>>

Snaps the Rectangle to unsigned integer coordinates.

pub fn expand(self, padding: impl Into<Padding>) -> Rectangle

Expands the Rectangle a given amount.

pub fn shrink(self, padding: impl Into<Padding>) -> Rectangle

Shrinks the Rectangle a given amount.

pub fn rotate(self, rotation: Radians) -> Rectangle

Rotates the Rectangle and returns the smallest Rectangle containing it.

pub fn zoom(self, zoom: f32) -> Rectangle

Scales the Rectangle without changing its position, effectively “zooming” it.

pub fn anchor( &self, size: Size, align_x: impl Into<Horizontal>, align_y: impl Into<Vertical>, ) -> Point

Returns the top-left position to render an object of the given Size. inside the Rectangle that is anchored to the edge or corner defined by the alignment arguments.