pub struct Daemon<A: Program> { /* private fields */ }Implementations
Sourceimpl<P: Program> Daemon<P>
impl<P: Program> Daemon<P>
pub fn run(self) -> Result
pub fn settings(self, settings: Settings) -> Self
Sourcepub fn antialiasing(self, antialiasing: bool) -> Self
pub fn antialiasing(self, antialiasing: bool) -> Self
Sets the Settings::antialiasing of the Daemon.
Sourcepub fn default_font(self, default_font: Font) -> Self
pub fn default_font(self, default_font: Font) -> Self
Sourcepub fn layer_settings(self, layer_settings: LayerShellSettings) -> Self
pub fn layer_settings(self, layer_settings: LayerShellSettings) -> Self
Sets the layershell setting of the Daemon
Sourcepub fn font(self, font: impl Into<Cow<'static, [u8]>>) -> Self
pub fn font(self, font: impl Into<Cow<'static, [u8]>>) -> Self
Adds a font to the list of fonts that will be loaded at the start of the Daemon.
Sourcepub fn default_text_size<Pixels: Into<Pixels>>(
self,
default_text_size: Pixels,
) -> Self
pub fn default_text_size<Pixels: Into<Pixels>>( self, default_text_size: Pixels, ) -> Self
set the default_text_size
Sourcepub fn style(
self,
f: impl Fn(&P::State, &P::Theme) -> Style,
) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
pub fn style( self, f: impl Fn(&P::State, &P::Theme) -> Style, ) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
Sets the style logic of the Daemon.
Sourcepub fn subscription(
self,
f: impl Fn(&P::State) -> Subscription<P::Message>,
) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
pub fn subscription( self, f: impl Fn(&P::State) -> Subscription<P::Message>, ) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
Sets the subscription logic of the Daemon.
Sourcepub fn title(
self,
f: impl Fn(&P::State, Id) -> Option<String>,
) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
pub fn title( self, f: impl Fn(&P::State, Id) -> Option<String>, ) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
Sets the subscription logic of the Daemon.
Sourcepub fn theme(
self,
f: impl ThemeFn<P::State, P::Theme>,
) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
pub fn theme( self, f: impl ThemeFn<P::State, P::Theme>, ) -> Daemon<impl Program<State = P::State, Message = P::Message, Theme = P::Theme>>
Sets the theme logic of the Daemon.